Seantis Translators
===================

A directory of translators working for Zug PD.

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.translators.png
  :target: https://travis-ci.org/seantis/seantis.translators
  :alt: Build Status

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.translators/badge.png?branch=master
  :target: https://coveralls.io/r/seantis/seantis.translators?branch=master
  :alt: Project Coverage

Latests PyPI Release
--------------------
.. image:: https://img.shields.io/pypi/v/seantis.translators.svg
  :target: https://pypi.python.org/pypi/seantis.translators
  :alt: Latest PyPI Release

License
-------
seantis.translators is released under GPLv2
